@@ -71,14 +71,14 @@
 //! // Reader needs to be mutable if any operations are used.
 //! let mut reader = subscriber
 //!   .create_datareader_no_key::<SomeType, CDRDeserializerAdapter<SomeType>>(
-//!     some_topic.clone(),
+//!     &some_topic,
 //!     None)
 //!   .unwrap();
 //!
 //! // Creating DataWriter required type and serializer adapter (which is recommended to be CDR).
 //! let writer = publisher
 //!   .create_datawriter_no_key::<SomeType, CDRSerializerAdapter<SomeType>>(
-//!     some_topic,
+//!     &some_topic,
 //!     None)
 //!   .unwrap();
 //!
@@ -143,15 +143,17 @@ pub mod data_types {
   };
   #[doc(inline)]
   pub use crate::structure::duration::Duration as DDSDuration;
-  pub use super::{readcondition::ReadCondition, traits::key::BuiltInTopicKey};
+  pub use super::{
+    readcondition::ReadCondition,
+    topic::{Topic, TopicKind},
+    traits::key::BuiltInTopicKey,
+  };
   #[doc(inline)]
   pub use super::with_key::datareader::SelectByKey;
   #[doc(inline)]
   pub use crate::structure::time::Timestamp as DDSTimestamp;
   // TODO: move typedesc module somewhere better
   pub use crate::dds::typedesc::TypeDesc;
-  #[doc(inline)]
-  pub use crate::structure::topic_kind::TopicKind; // AKA dds::topic::TopicKind
 }
 
 /// DDS Error
@@ -160,7 +162,7 @@ pub mod error {
 }
 
 pub use participant::DomainParticipant;
-pub use topic::Topic;
+pub use topic::{Topic, TopicKind};
 pub use pubsub::{Publisher, Subscriber};
 #[doc(inline)]
 pub use with_key::datawriter::DataWriter as With_Key_DataWriter;
