@@ -3,7 +3,7 @@ use std::{
   collections::HashMap,
   io::ErrorKind,
   net::Ipv4Addr,
-  sync::{Arc, Mutex, RwLock, Weak},
+  sync::{atomic, Arc, Mutex, RwLock, Weak},
   thread,
   thread::JoinHandle,
   time::{Duration, Instant},
@@ -16,8 +16,8 @@ use log::{debug, error, info, trace, warn};
 
 use crate::{
   dds::{
-    data_types::*, dp_event_loop::DPEventLoop, pubsub::*, qos::*, reader::*, topic::*, typedesc::*,
-    values::result::*, writer::*,
+    data_types::*, dp_event_loop::DPEventLoop, pubsub::*, qos::*, reader::*, topic::*,
+    typedesc::TypeDesc, values::result::*, writer::WriterIngredients,
   },
   discovery::{
     data_types::topic_data::DiscoveredTopicData,
@@ -25,11 +25,7 @@ use crate::{
     discovery_db::DiscoveryDB,
   },
   log_and_err_internal,
-  network::{
-    constant::*,
-    udp_listener::UDPListener,
-    util::{get_local_multicast_locators, get_local_unicast_locators},
-  },
+  network::{constant::*, udp_listener::UDPListener},
   structure::{dds_cache::DDSCache, entity::RTPSEntity, guid::GUID, locator::Locator},
 };
 use super::dp_event_loop::DomainInfo;
@@ -109,7 +105,7 @@ impl DomainParticipant {
           spdp_liveness_receiver,
           self_locators,
         ) {
-          discovery.discovery_event_loop() // run the event loop
+          discovery.discovery_event_loop(); // run the event loop
         }
       })?;
 
@@ -268,7 +264,7 @@ impl DomainParticipant {
   }
 
   pub(crate) fn weak_clone(&self) -> DomainParticipantWeak {
-    DomainParticipantWeak::new(self.clone(), self.guid())
+    DomainParticipantWeak::new(self, self.guid())
   }
 
   pub(crate) fn dds_cache(&self) -> Arc<RwLock<DDSCache>> {
@@ -286,7 +282,15 @@ impl DomainParticipant {
       .discovery_db
       .clone()
   }
-}
+
+  pub(crate) fn new_entity_id(&self, entity_kind: EntityKind) -> EntityId {
+    self.dpi.lock().unwrap().new_entity_id(entity_kind)
+  }
+
+  pub(crate) fn self_locators(&self) -> HashMap<Token, Vec<Locator>> {
+    self.dpi.lock().unwrap().self_locators()
+  }
+} // end impl DomainParticipant
 
 impl PartialEq for DomainParticipant {
   fn eq(&self, other: &Self) -> bool {
@@ -304,7 +308,7 @@ pub struct DomainParticipantWeak {
 }
 
 impl DomainParticipantWeak {
-  pub fn new(dp: DomainParticipant, guid: GUID) -> DomainParticipantWeak {
+  pub fn new(dp: &DomainParticipant, guid: GUID) -> DomainParticipantWeak {
     DomainParticipantWeak {
       dpi: Arc::downgrade(&dp.dpi),
       guid,
@@ -385,10 +389,10 @@ impl RTPSEntity for DomainParticipantWeak {
 pub(crate) struct DomainParticipantDisc {
   dpi: Arc<Mutex<DomainParticipantInner>>,
   // Discovery control
-  //discovery_updated_sender: mio_channel::SyncSender<DiscoveryNotificationType>,
-  //discovery_command_receiver: mio_channel::Receiver<DiscoveryCommand>,
   discovery_command_sender: mio_channel::SyncSender<DiscoveryCommand>,
   discovery_join_handle: mio_channel::Receiver<JoinHandle<()>>,
+  // This allows deterministic generation of EntityIds for DataReader, DataWriter, etc.
+  entity_id_generator: atomic::AtomicU32,
 }
 
 impl DomainParticipantDisc {
@@ -407,13 +411,22 @@ impl DomainParticipantDisc {
 
     Ok(DomainParticipantDisc {
       dpi: Arc::new(Mutex::new(dpi)),
-      //discovery_updated_sender,
-      //discovery_command_receiver,
       discovery_command_sender,
       discovery_join_handle,
+      entity_id_generator: atomic::AtomicU32::new(0),
     })
   }
 
+  // This generates identifiers that consist of given EntityKind and arbitrary,
+  // unique identifier.
+  pub(crate) fn new_entity_id(&self, entity_kind: EntityKind) -> EntityId {
+    let [_goldilocks, papa_byte, mama_byte, baby_byte] = self
+      .entity_id_generator
+      .fetch_add(1, atomic::Ordering::Relaxed)
+      .to_be_bytes();
+    EntityId::new([papa_byte, mama_byte, baby_byte], entity_kind)
+  }
+
   pub fn create_publisher(
     &self,
     dp: &DomainParticipantWeak,
@@ -663,15 +676,8 @@ impl DomainParticipantInner {
     // construct our own Locators
     let self_locators: HashMap<Token, Vec<Locator>> = listeners
       .iter()
-      .map(|(t, l)| match l.to_socketaddr() {
-        Ok(sa) => {
-          let locs = if sa.ip().is_multicast() {
-            get_local_multicast_locators(sa.port())
-          } else {
-            get_local_unicast_locators(sa.port())
-          };
-          (*t, locs)
-        }
+      .map(|(t, l)| match l.to_locator_address() {
+        Ok(locs) => (*t, locs),
         Err(e) => {
           error!("No local network address for token {:?}: {:?}", t, e);
           (*t, vec![])
@@ -689,7 +695,7 @@ impl DomainParticipantInner {
       mio_channel::sync_channel::<WriterIngredients>(10);
     let (remove_writer_sender, remove_writer_receiver) = mio_channel::sync_channel::<GUID>(10);
 
-    let new_guid = GUID::new_particiapnt_guid();
+    let new_guid = GUID::new_participant_guid();
     let domain_info = DomainInfo {
       domain_participant_guid: new_guid,
       domain_id,
@@ -739,7 +745,7 @@ impl DomainParticipantInner {
           discovery_update_notification_receiver,
           spdp_liveness_sender,
         );
-        dp_event_loop.event_loop()
+        dp_event_loop.event_loop();
       })?;
 
     info!(
@@ -1046,7 +1052,7 @@ mod tests {
       .expect("Failed to create topic");
 
     let mut _data_writer = publisher
-      .create_datawriter::<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>>(topic, None)
+      .create_datawriter::<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>>(&topic, None)
       .expect("Failed to create datawriter");
   }
 
@@ -1072,7 +1078,7 @@ mod tests {
       .expect("Failed to create topic");
 
     let mut _data_writer = publisher
-      .create_datawriter::<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>>(topic, None)
+      .create_datawriter::<RandomData, CDRSerializerAdapter<RandomData, LittleEndian>>(&topic, None)
       .expect("Failed to create datawriter");
 
     let port_number: u16 = user_traffic_unicast_port(5, 0);
