@@ -7,7 +7,6 @@ use std::{
 use mio_extras::channel as mio_channel;
 use serde::{de::DeserializeOwned, Serialize};
 use byteorder::LittleEndian;
-use rand::Rng;
 
 use crate::{
   dds::{
@@ -18,13 +17,13 @@ use crate::{
     participant::*,
     qos::*,
     reader::ReaderIngredients,
-    statusevents::*,
+    statusevents::DataReaderStatus,
     topic::*,
     traits::{
       key::{Key, Keyed},
-      serde_adapters::*,
+      serde_adapters::{no_key, with_key},
     },
-    values::result::*,
+    values::result::{Error, Result},
     with_key::{
       datareader::DataReader as WithKeyDataReader, datawriter::DataWriter as WithKeyDataWriter,
     },
@@ -125,11 +124,11 @@ impl Publisher {
   /// }
   ///
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(topic, None);
+  /// let data_writer = publisher.create_datawriter::<SomeType, CDRSerializerAdapter<_>>(&topic, None);
   /// ```
   pub fn create_datawriter<D, SA>(
     &self,
-    topic: Topic,
+    topic: &Topic,
     qos: Option<QosPolicies>,
   ) -> Result<WithKeyDataWriter<D, SA>>
   where
@@ -144,7 +143,7 @@ impl Publisher {
   /// Endian
   pub fn create_datawriter_cdr<D>(
     &self,
-    topic: Topic,
+    topic: &Topic,
     qos: Option<QosPolicies>,
   ) -> Result<WithKeyDataWriter<D, CDRSerializerAdapter<D, LittleEndian>>>
   where
@@ -159,7 +158,7 @@ impl Publisher {
   pub(crate) fn create_datawriter_with_entityid<D, SA>(
     &self,
     entity_id: EntityId,
-    topic: Topic,
+    topic: &Topic,
     qos: Option<QosPolicies>,
   ) -> Result<WithKeyDataWriter<D, SA>>
   where
@@ -175,7 +174,7 @@ impl Publisher {
   pub(crate) fn create_datawriter_cdr_with_entityid<D>(
     &self,
     entity_id: EntityId,
-    topic: Topic,
+    topic: &Topic,
     qos: Option<QosPolicies>,
   ) -> Result<WithKeyDataWriter<D, CDRSerializerAdapter<D, LittleEndian>>>
   where
@@ -214,11 +213,11 @@ impl Publisher {
   /// struct SomeType {}
   ///
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(topic, None);
+  /// let data_writer = publisher.create_datawriter_no_key::<SomeType, CDRSerializerAdapter<_>>(&topic, None);
   /// ```
   pub fn create_datawriter_no_key<D, SA>(
     &self,
-    topic: Topic,
+    topic: &Topic,
     qos: Option<QosPolicies>,
   ) -> Result<NoKeyDataWriter<D, SA>>
   where
@@ -230,7 +229,7 @@ impl Publisher {
 
   pub fn create_datawriter_no_key_cdr<D>(
     &self,
-    topic: Topic,
+    topic: &Topic,
     qos: Option<QosPolicies>,
   ) -> Result<NoKeyDataWriter<D, CDRSerializerAdapter<D, LittleEndian>>>
   where
@@ -244,7 +243,7 @@ impl Publisher {
   pub(crate) fn create_datawriter_no_key_with_entityid<D, SA>(
     &self,
     entity_id: EntityId,
-    topic: Topic,
+    topic: &Topic,
     qos: Option<QosPolicies>,
   ) -> Result<NoKeyDataWriter<D, SA>>
   where
@@ -259,7 +258,7 @@ impl Publisher {
   pub(crate) fn create_datawriter_no_key_cdr_with_entityid<D>(
     &self,
     entity_id: EntityId,
-    topic: Topic,
+    topic: &Topic,
     qos: Option<QosPolicies>,
   ) -> Result<NoKeyDataWriter<D, CDRSerializerAdapter<D, LittleEndian>>>
   where
@@ -425,7 +424,7 @@ impl InnerPublisher {
     &self,
     outer: &Publisher,
     entity_id_opt: Option<EntityId>,
-    topic: Topic,
+    topic: &Topic,
     optional_qos: Option<QosPolicies>,
   ) -> Result<WithKeyDataWriter<D, SA>>
   where
@@ -452,7 +451,7 @@ impl InnerPublisher {
       .modify_by(&optional_qos.unwrap_or_else(QosPolicies::qos_none));
 
     let entity_id =
-      unwrap_or_random_entity_id(entity_id_opt, EntityKind::WRITER_WITH_KEY_USER_DEFINED);
+      self.unwrap_or_random_entity_id(entity_id_opt, EntityKind::WRITER_WITH_KEY_USER_DEFINED);
     let dp = self
       .participant()
       .ok_or("upgrade fail")
@@ -485,9 +484,9 @@ impl InnerPublisher {
 
     // notify Discovery DB
     let mut db = self.discovery_db.write()?;
-    let dwd = DiscoveredWriterData::new(&data_writer, &topic, &dp);
+    let dwd = DiscoveredWriterData::new(&data_writer, topic, &dp);
     db.update_local_topic_writer(dwd);
-    db.update_topic_data_p(&topic);
+    db.update_topic_data_p(topic);
 
     Ok(data_writer)
   }
@@ -496,7 +495,7 @@ impl InnerPublisher {
     &self,
     outer: &Publisher,
     entity_id_opt: Option<EntityId>,
-    topic: Topic,
+    topic: &Topic,
     qos: Option<QosPolicies>,
   ) -> Result<NoKeyDataWriter<D, SA>>
   where
@@ -504,7 +503,7 @@ impl InnerPublisher {
     SA: no_key::SerializerAdapter<D>,
   {
     let entity_id =
-      unwrap_or_random_entity_id(entity_id_opt, EntityKind::WRITER_NO_KEY_USER_DEFINED);
+      self.unwrap_or_random_entity_id(entity_id_opt, EntityKind::WRITER_NO_KEY_USER_DEFINED);
     let d = self.create_datawriter::<NoKeyWrapper<D>, SAWrapper<SA>>(
       outer,
       Some(entity_id),
@@ -552,6 +551,16 @@ impl InnerPublisher {
   pub fn set_default_datawriter_qos(&mut self, q: &QosPolicies) {
     self.default_datawriter_qos = q.clone();
   }
+
+  fn unwrap_or_random_entity_id(
+    &self,
+    entity_id_opt: Option<EntityId>,
+    entity_kind: EntityKind,
+  ) -> EntityId {
+    // If the entity_id is given, then just use that. If not, then pull an arbirtaty
+    // number out of participant's hat.
+    entity_id_opt.unwrap_or_else(|| self.participant().unwrap().new_entity_id(entity_kind))
+  }
 }
 
 impl PartialEq for InnerPublisher {
@@ -663,11 +672,11 @@ impl Subscriber {
   /// }
   ///
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(topic, None);
+  /// let data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(&topic, None);
   /// ```
   pub fn create_datareader<D: 'static, SA>(
     &self,
-    topic: Topic,
+    topic: &Topic,
     qos: Option<QosPolicies>,
   ) -> Result<WithKeyDataReader<D, SA>>
   where
@@ -680,7 +689,7 @@ impl Subscriber {
 
   pub fn create_datareader_cdr<D: 'static>(
     &self,
-    topic: Topic,
+    topic: &Topic,
     qos: Option<QosPolicies>,
   ) -> Result<WithKeyDataReader<D, CDRDeserializerAdapter<D>>>
   where
@@ -694,7 +703,7 @@ impl Subscriber {
 
   pub(crate) fn create_datareader_with_entityid<D: 'static, SA>(
     &self,
-    topic: Topic,
+    topic: &Topic,
     entity_id: EntityId,
     qos: Option<QosPolicies>,
   ) -> Result<WithKeyDataReader<D, SA>>
@@ -710,7 +719,7 @@ impl Subscriber {
 
   pub(crate) fn create_datareader_cdr_with_entityid<D: 'static>(
     &self,
-    topic: Topic,
+    topic: &Topic,
     entity_id: EntityId,
     qos: Option<QosPolicies>,
   ) -> Result<WithKeyDataReader<D, CDRDeserializerAdapter<D>>>
@@ -751,11 +760,11 @@ impl Subscriber {
   /// struct SomeType {}
   ///
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::NoKey).unwrap();
-  /// let data_reader = subscriber.create_datareader_no_key::<SomeType, CDRDeserializerAdapter<_>>(topic, None);
+  /// let data_reader = subscriber.create_datareader_no_key::<SomeType, CDRDeserializerAdapter<_>>(&topic, None);
   /// ```
   pub fn create_datareader_no_key<D: 'static, SA>(
     &self,
-    topic: Topic,
+    topic: &Topic,
     qos: Option<QosPolicies>,
   ) -> Result<NoKeyDataReader<D, SA>>
   where
@@ -767,7 +776,7 @@ impl Subscriber {
 
   pub fn create_datareader_no_key_cdr<D: 'static>(
     &self,
-    topic: Topic,
+    topic: &Topic,
     qos: Option<QosPolicies>,
   ) -> Result<NoKeyDataReader<D, CDRDeserializerAdapter<D>>>
   where
@@ -778,7 +787,7 @@ impl Subscriber {
 
   pub(crate) fn create_datareader_no_key_with_entityid<D: 'static, SA>(
     &self,
-    topic: Topic,
+    topic: &Topic,
     entity_id: EntityId,
     qos: Option<QosPolicies>,
   ) -> Result<NoKeyDataReader<D, SA>>
@@ -793,7 +802,7 @@ impl Subscriber {
 
   pub(crate) fn create_datareader_no_key_cdr_with_entityid<D: 'static>(
     &self,
-    topic: Topic,
+    topic: &Topic,
     entity_id: EntityId,
     qos: Option<QosPolicies>,
   ) -> Result<NoKeyDataReader<D, CDRDeserializerAdapter<D>>>
@@ -877,7 +886,7 @@ impl InnerSubscriber {
     &self,
     outer: &Subscriber,
     entity_id_opt: Option<EntityId>,
-    topic: Topic,
+    topic: &Topic,
     optional_qos: Option<QosPolicies>,
   ) -> Result<WithKeyDataReader<D, SA>>
   where
@@ -901,7 +910,7 @@ impl InnerSubscriber {
       .modify_by(&optional_qos.unwrap_or_else(QosPolicies::qos_none));
 
     let entity_id =
-      unwrap_or_random_entity_id(entity_id_opt, EntityKind::READER_WITH_KEY_USER_DEFINED);
+      self.unwrap_or_random_entity_id(entity_id_opt, EntityKind::READER_WITH_KEY_USER_DEFINED);
 
     let reader_id = entity_id;
     let datareader_id = entity_id;
@@ -927,8 +936,8 @@ impl InnerSubscriber {
         .discovery_db
         .write()
         .or_else(|e| log_and_err_internal!("Cannot lock discovery_db. {}", e))?;
-      db.update_local_topic_reader(&dp, &topic, &new_reader);
-      db.update_topic_data_p(&topic);
+      db.update_local_topic_reader(&dp, topic, &new_reader);
+      db.update_topic_data_p(topic);
     }
 
     let datareader = WithKeyDataReader::<D, SA>::new(
@@ -963,7 +972,7 @@ impl InnerSubscriber {
   pub fn create_datareader<D: 'static, SA>(
     &self,
     outer: &Subscriber,
-    topic: Topic,
+    topic: &Topic,
     entity_id: Option<EntityId>,
     qos: Option<QosPolicies>,
   ) -> Result<WithKeyDataReader<D, SA>>
@@ -983,7 +992,7 @@ impl InnerSubscriber {
   pub fn create_datareader_no_key<D: 'static, SA>(
     &self,
     outer: &Subscriber,
-    topic: Topic,
+    topic: &Topic,
     entity_id_opt: Option<EntityId>,
     qos: Option<QosPolicies>,
   ) -> Result<NoKeyDataReader<D, SA>>
@@ -998,7 +1007,7 @@ impl InnerSubscriber {
     }
 
     let entity_id =
-      unwrap_or_random_entity_id(entity_id_opt, EntityKind::READER_NO_KEY_USER_DEFINED);
+      self.unwrap_or_random_entity_id(entity_id_opt, EntityKind::READER_NO_KEY_USER_DEFINED);
 
     let d = self.create_datareader_internal::<NoKeyWrapper<D>, DAWrapper<SA>>(
       outer,
@@ -1013,17 +1022,16 @@ impl InnerSubscriber {
   pub fn participant(&self) -> Option<DomainParticipant> {
     self.domain_participant.clone().upgrade()
   }
-}
 
-fn unwrap_or_random_entity_id(
-  entity_id_opt: Option<EntityId>,
-  entity_kind: EntityKind,
-) -> EntityId {
-  entity_id_opt // use the given EntityId or generate new random one
-    .unwrap_or_else(|| {
-      let mut rng = rand::thread_rng();
-      EntityId::create_custom_entity_id([rng.gen(), rng.gen(), rng.gen()], entity_kind)
-    })
+  fn unwrap_or_random_entity_id(
+    &self,
+    entity_id_opt: Option<EntityId>,
+    entity_kind: EntityKind,
+  ) -> EntityId {
+    // If the entity_id is given, then just use that. If not, then pull an arbirtaty
+    // number out of participant's hat.
+    entity_id_opt.unwrap_or_else(|| self.participant().unwrap().new_entity_id(entity_kind))
+  }
 }
 
 // -------------------------------------------------------------------
