@@ -1,14 +1,15 @@
 use enumflags2::BitFlags;
 
-use crate::{structure::guid::GUID};
-use crate::structure::time::Timestamp;
+use crate::structure::{guid::GUID, time::Timestamp};
 
 //use std::num::Zero; // unstable
 
 /// DDS spec 2.2.2.5.4
-/// "Read" indicates whether or not the corresponding data sample has already been read.
+/// "Read" indicates whether or not the corresponding data sample has already
+/// been read.
 #[derive(BitFlags, Debug, Copy, Clone, PartialEq)]
-#[repr(u32)] // DDS Spec 1.4 section 2.3.3 DCPS PSM : IDL defines these as "unsigned long", so u32
+#[repr(u32)] // DDS Spec 1.4 section 2.3.3 DCPS PSM : IDL defines these as "unsigned long",
+             // so u32
 pub enum SampleState {
   Read = 0b0001,
   NotRead = 0b0010,
@@ -22,14 +23,13 @@ impl SampleState {
 }
 
 /// DDS spec 2.2.2.5.1.8
-///
 #[derive(BitFlags, Debug, Copy, Clone, PartialEq)]
 #[repr(u32)]
 pub enum ViewState {
   ///  indicates that either this is the first time that the DataReader has ever
-  /// accessed samples of that instance, or else that the DataReader has accessed previous
-  /// samples of the instance, but the instance has since been reborn (i.e., become
-  /// not-alive and then alive again).
+  /// accessed samples of that instance, or else that the DataReader has
+  /// accessed previous samples of the instance, but the instance has since
+  /// been reborn (i.e., become not-alive and then alive again).
   New = 0b0001,
   /// indicates that the DataReader has already accessed samples of the same
   ///instance and that the instance has not been reborn since
