@@ -109,7 +109,7 @@ impl CurrentStatusChanges {
 ///
 /// // WithKey is important
 /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-/// let data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(topic, None);
+/// let data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(&topic, None);
 /// ```
 pub struct DataReader<
   D: Keyed + DeserializeOwned,
@@ -145,7 +145,7 @@ where
     {
       Ok(_) => {}
       Err(mio_channel::SendError::Disconnected(_)) => {
-        debug!("Failed to send REMOVE_LOCAL_READER DiscoveryCommand. Maybe shutting down?")
+        debug!("Failed to send REMOVE_LOCAL_READER DiscoveryCommand. Maybe shutting down?");
       }
       Err(e) => error!(
         "Failed to send REMOVE_LOCAL_READER DiscoveryCommand. {:?}",
@@ -242,7 +242,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(topic, None).unwrap();
+  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// // Wait for data to arrive...
   ///
@@ -306,7 +306,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(topic, None).unwrap();
+  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// // Wait for data to arrive...
   ///
@@ -364,7 +364,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(topic, None).unwrap();
+  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// // Wait for data to arrive...
   ///
@@ -406,7 +406,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(topic, None).unwrap();
+  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// // Wait for data to arrive...
   ///
@@ -452,7 +452,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(topic, None).unwrap();
+  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// // Wait for data to arrive...
   ///
@@ -502,7 +502,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(topic, None).unwrap();
+  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// // Wait for data to arrive...
   ///
@@ -557,7 +557,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(topic, None).unwrap();
+  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// // Wait for data to arrive...
   ///
@@ -609,7 +609,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(topic, None).unwrap();
+  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// // Wait for data to arrive...
   ///
@@ -688,13 +688,11 @@ where
             // Check that SequenceNumber always goes forward.
             // Getting the same SN means duplicate packet, which we must drop.
             latest_sequence_number_have_already
-              .map( |latest| sequence_number > latest)
-              .unwrap_or(true))
+              .map_or(true,  |latest| sequence_number > latest))
         || (is_reliable &&
             // Check that we get all the sequence numbers in order
             latest_sequence_number_have_already
-              .map( |latest| *latest + SequenceNumber::from(1) == *sequence_number)
-              .unwrap_or(true))
+              .map_or(true, |latest| *latest + SequenceNumber::from(1) == *sequence_number))
       {
         // normal case: sequence_number not seen before
         // first, update our last-seen-pointer
@@ -748,9 +746,12 @@ where
               serialized_key.representation_identifier,
             ) {
               Ok(key) => {
-                self
-                  .datasample_cache
-                  .add_sample(Err(key), *writer_guid, instant, *source_timestamp)
+                self.datasample_cache.add_sample(
+                  Err(key),
+                  *writer_guid,
+                  instant,
+                  *source_timestamp,
+                );
               }
               Err(e) => {
                 warn!(
@@ -771,9 +772,9 @@ where
             if let Some(key) = self.datasample_cache.key_by_hash(*key_hash) {
               self
                 .datasample_cache
-                .add_sample(Err(key), *writer_guid, instant, *source_timestamp)
+                .add_sample(Err(key), *writer_guid, instant, *source_timestamp);
             } else {
-              warn!("Tried to dispose with unkonwn key hash: {:x?}", key_hash)
+              warn!("Tried to dispose with unkonwn key hash: {:x?}", key_hash);
             }
           } /*
             DDSData::DataFrags { representation_identifier, bytes_frags } => {
@@ -861,7 +862,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(topic, None).unwrap();
+  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// // Wait for data to arrive...
   ///
@@ -894,7 +895,7 @@ where
 
     let mut selected = self
       .datasample_cache
-      .select_instance_keys_for_access(key, read_condition);
+      .select_instance_keys_for_access(&key, read_condition);
     selected.truncate(max_samples);
 
     let result = self.datasample_cache.read_by_keys(&selected);
@@ -934,7 +935,7 @@ where
   ///
   /// // WithKey is important
   /// let topic = domain_participant.create_topic("some_topic".to_string(), "SomeType".to_string(), &qos, TopicKind::WithKey).unwrap();
-  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(topic, None).unwrap();
+  /// let mut data_reader = subscriber.create_datareader::<SomeType, CDRDeserializerAdapter<_>>(&topic, None).unwrap();
   ///
   /// // Wait for data to arrive...
   ///
@@ -967,7 +968,7 @@ where
 
     let mut selected = self
       .datasample_cache
-      .select_instance_keys_for_access(key, read_condition);
+      .select_instance_keys_for_access(&key, read_condition);
     selected.truncate(max_samples);
 
     let result = self.datasample_cache.take_by_keys(&selected);
@@ -1330,7 +1331,7 @@ mod tests {
     );
 
     let mut matching_datareader = sub
-      .create_datareader::<RandomData, CDRDeserializerAdapter<RandomData>>(topic, None)
+      .create_datareader::<RandomData, CDRDeserializerAdapter<RandomData>>(&topic, None)
       .unwrap();
 
     let random_data = RandomData {
@@ -1372,7 +1373,7 @@ mod tests {
       ..Default::default()
     };
 
-    new_reader.handle_data_msg(data, data_flags, mr_state.clone());
+    new_reader.handle_data_msg(data, data_flags, &mr_state);
 
     matching_datareader.fill_local_datasample_cache();
     let deserialized_random_data = matching_datareader.read(1, ReadCondition::any()).unwrap()[0]
@@ -1415,8 +1416,8 @@ mod tests {
       ..Default::default()
     };
 
-    new_reader.handle_data_msg(data2, data_flags, mr_state.clone());
-    new_reader.handle_data_msg(data3, data_flags, mr_state);
+    new_reader.handle_data_msg(data2, data_flags, &mr_state);
+    new_reader.handle_data_msg(data3, data_flags, &mr_state);
 
     matching_datareader.fill_local_datasample_cache();
     let random_data_vec = matching_datareader
@@ -1470,7 +1471,7 @@ mod tests {
     );
 
     let mut datareader = sub
-      .create_datareader::<RandomData, CDRDeserializerAdapter<RandomData>>(topic, None)
+      .create_datareader::<RandomData, CDRDeserializerAdapter<RandomData>>(&topic, None)
       .unwrap();
 
     let writer_guid = GUID {
@@ -1527,8 +1528,8 @@ mod tests {
 
     let data_flags = DATA_Flags::Endianness | DATA_Flags::Data;
 
-    reader.handle_data_msg(data_msg, data_flags, mr_state.clone());
-    reader.handle_data_msg(data_msg2, data_flags, mr_state.clone());
+    reader.handle_data_msg(data_msg, data_flags, &mr_state);
+    reader.handle_data_msg(data_msg2, data_flags, &mr_state);
 
     // Read the same sample two times.
     {
@@ -1598,7 +1599,7 @@ mod tests {
         representation_options: [0, 0],
         value: Bytes::from(to_bytes::<RandomData, LittleEndian>(&data_key1).unwrap()),
       }),
-      ..Default::default()
+      ..Data::default()
     };
     let data_msg2 = Data {
       reader_id: reader.entity_id(),
@@ -1609,7 +1610,7 @@ mod tests {
         representation_options: [0, 0],
         value: Bytes::from(to_bytes::<RandomData, LittleEndian>(&data_key2_1).unwrap()),
       }),
-      ..Default::default()
+      ..Data::default()
     };
     let data_msg3 = Data {
       reader_id: reader.entity_id(),
@@ -1620,7 +1621,7 @@ mod tests {
         representation_options: [0, 0],
         value: Bytes::from(to_bytes::<RandomData, LittleEndian>(&data_key2_2).unwrap()),
       }),
-      ..Default::default()
+      ..Data::default()
     };
     let data_msg4 = Data {
       reader_id: reader.entity_id(),
@@ -1631,12 +1632,12 @@ mod tests {
         representation_options: [0, 0],
         value: Bytes::from(to_bytes::<RandomData, LittleEndian>(&data_key2_3).unwrap()),
       }),
-      ..Default::default()
+      ..Data::default()
     };
-    reader.handle_data_msg(data_msg, data_flags, mr_state.clone());
-    reader.handle_data_msg(data_msg2, data_flags, mr_state.clone());
-    reader.handle_data_msg(data_msg3, data_flags, mr_state.clone());
-    reader.handle_data_msg(data_msg4, data_flags, mr_state);
+    reader.handle_data_msg(data_msg, data_flags, &mr_state);
+    reader.handle_data_msg(data_msg2, data_flags, &mr_state);
+    reader.handle_data_msg(data_msg3, data_flags, &mr_state);
+    reader.handle_data_msg(data_msg4, data_flags, &mr_state);
 
     info!("calling read with key 1 and this");
     let results =
