@@ -15,11 +15,12 @@
 //! when communicating to ROS2 components.
 
 #![deny(clippy::all)]
+#![warn(clippy::needless_pass_by_value, clippy::semicolon_if_nothing_returned)]
 #![allow(
   clippy::option_map_unit_fn,
   // option_map_unit_fn suggests changing option.map( ) with () return value to if let -construct,
   // but that may break code flow.
-  dead_code
+  dead_code,
 )]
 
 #[macro_use]
