@@ -1,7 +1,8 @@
-use speedy::{Readable, Writable};
-use serde::{Serialize, Deserialize};
 use std::ops::{Add, Sub};
 
+use speedy::{Readable, Writable};
+use serde::{Deserialize, Serialize};
+
 use super::duration::Duration;
 
 /// Quoting RTPS 2.3 spec 9.3.2.1:
@@ -11,13 +12,13 @@ use super::duration::Duration;
 /// > expressed in seconds and fraction of seconds using the formula:
 /// > time = seconds + (fraction / 2^(32))
 ///
-/// > The time origin is represented by the reserved value TIME_ZERO and corresponds
-/// > to the UNIX prime epoch 0h, 1 January 1970.
+/// > The time origin is represented by the reserved value TIME_ZERO and
+/// corresponds > to the UNIX prime epoch 0h, 1 January 1970.
 ///
 ///
-/// *Note* : NTP does not use the Unix epoch (1970-01-01 00:00) but the beginning of
-/// the 20th century epoch (1900-01-01 00:00) insted. So these timestamps are not the same
-/// as in NTP.
+/// *Note* : NTP does not use the Unix epoch (1970-01-01 00:00) but the
+/// beginning of the 20th century epoch (1900-01-01 00:00) insted. So these
+/// timestamps are not the same as in NTP.
 
 /// This time representation is used in RTPS messages.
 /// This is called Time_t in the RTPS spec.
