@@ -1,5 +1,6 @@
-use crate::dds::traits::key::{Keyed};
-use serde::{Serialize, Deserialize};
+use serde::{Deserialize, Serialize};
+
+use crate::dds::traits::key::Keyed;
 
 #[derive(Serialize, Debug, Clone, PartialEq, Deserialize)]
 pub struct ShapeType {
@@ -8,7 +9,7 @@ pub struct ShapeType {
 
 impl Keyed for ShapeType {
   type K = i32;
-  fn get_key(&self) -> Self::K {
+  fn key(&self) -> Self::K {
     self.a
   }
 }
