@@ -124,19 +124,19 @@ use crate::{
 pub(crate) fn spdp_participant_msg() -> Message {
   let data = spdp_participant_data_raw();
 
-  Message::read_from_buffer(data).unwrap()
+  Message::read_from_buffer(&data).unwrap()
 }
 
 pub(crate) fn spdp_subscription_msg() -> Message {
   let data = spdp_subscription_data_raw();
 
-  Message::read_from_buffer(data).unwrap()
+  Message::read_from_buffer(&data).unwrap()
 }
 
 pub(crate) fn spdp_publication_msg() -> Message {
   let data = spdp_publication_data_raw();
 
-  Message::read_from_buffer(data).unwrap()
+  Message::read_from_buffer(&data).unwrap()
 }
 
 pub(crate) fn spdp_participant_msg_mod(port: u16) -> Message {
@@ -181,7 +181,7 @@ pub(crate) fn spdp_participant_msg_mod(port: u16) -> Message {
 pub(crate) fn spdp_participant_data() -> Option<SpdpDiscoveredParticipantData> {
   let data = spdp_participant_data_raw();
 
-  let rtpsmsg = Message::read_from_buffer(data).unwrap();
+  let rtpsmsg = Message::read_from_buffer(&data).unwrap();
   let submsgs = rtpsmsg.submessages();
 
   for submsg in submsgs.iter() {
